@@ -19,7 +19,7 @@ from django.http import HttpResponse
 from django.views.generic.edit import FormView
 
 
-class AjaxFormView(FormView):
+class AjaxFormViewMixin(object):
     def render_to_json_response(self, context, **response_kwargs):
         data = json.dumps(context)
         response_kwargs['content_type'] = 'application/json'
@@ -102,7 +102,7 @@ def activate(request, template_name='accounts/activate.html',
                               context_instance=context)
 
 
-class ChangePasswordView(AjaxFormView):
+class ChangePasswordView(FormView, AjaxFormViewMixin):
     template_name = 'accounts/change_password.html'
     form_class = UserChangePasswordForm
     success_url = '/accounts/profile/'
